@@ -50,8 +50,8 @@ STATICFILES_FINDERS = ["django.contrib.staticfiles.finders.FileSystemFinder",
 AUTHENTICATION_BACKENDS =  [ 'django.contrib.auth.backends.ModelBackend',]
 
 try:
-    DEBUG_TOOLBAR_CONFIG['INTERCEPT_REDIRECTS'] = False
+    DEBUG_TOOLBAR_CONFIG['DISABLE_PANELS'] = True
 except:
     DEBUG_TOOLBAR_CONFIG = {}
-    DEBUG_TOOLBAR_CONFIG['INTERCEPT_REDIRECTS'] = False
+    DEBUG_TOOLBAR_CONFIG['DISABLE_PANELS'] = True
 
